@@ -16,10 +16,11 @@ import qualified Codec.Binary.Base64 as B64
 import qualified Data.Text as T
 import qualified Data.Text.Encoding as T
 import qualified Data.ByteString as B
+import qualified Data.Semigroup as Sem
 
 -- | Newtype of ByteString so we can have JSON instances without orphans.
 newtype Val = Val { val :: B.ByteString }
-	deriving (Show, Generic, Eq, Monoid)
+	deriving (Show, Generic, Eq, Sem.Semigroup, Monoid)
 
 instance DataSize Val where
 	dataSize (Val b) = fromIntegral (B.length b)
